Macro alloy_primitives::try_vec
source · macro_rules! try_vec { () => { ... }; ($elem:expr; $n:expr) => { ... }; ($($x:expr),+ $(,)?) => { ... }; }
Tries to create a Vec of n elements, each initialized to elem.
macro_rules! try_vec { () => { ... }; ($elem:expr; $n:expr) => { ... }; ($($x:expr),+ $(,)?) => { ... }; }
Tries to create a Vec of n elements, each initialized to elem.