Struct alloy_primitives::LogData
source · pub struct LogData {
pub data: Bytes,
/* private fields */
}Expand description
An Ethereum event log object.
Fields
data: BytesThe plain data.
Implementations
sourceimpl LogData
impl LogData
sourcepub fn new_unchecked(topics: Vec<B256>, data: Bytes) -> Self
pub fn new_unchecked(topics: Vec<B256>, data: Bytes) -> Self
Creates a new log, without length-checking. This allows creation of invalid logs. May be safely used when the length of the topic list is known to be 4 or less.
sourcepub fn topics_mut(&mut self) -> &mut [B256]
pub fn topics_mut(&mut self) -> &mut [B256]
Get the topic list, mutably. This gives access to the internal array, without allowing extension of that array.
sourcepub fn topics_mut_unchecked(&mut self) -> &mut Vec<B256>
pub fn topics_mut_unchecked(&mut self) -> &mut Vec<B256>
Get a mutable reference to the topic list. This allows creation of invalid logs.
sourcepub fn set_topics_unchecked(&mut self, topics: Vec<B256>)
pub fn set_topics_unchecked(&mut self, topics: Vec<B256>)
Set the topic list, without length-checking. This allows creation of invalid logs.
sourcepub fn set_topics_truncating(&mut self, topics: Vec<B256>)
pub fn set_topics_truncating(&mut self, topics: Vec<B256>)
Set the topic list, truncating to 4 topics.